CodeSetFormat

Struct CodeSetFormat 

pub struct CodeSetFormat {
    pub code_set: Option<String>,
    pub multibyte_max_bytes: Option<u32>,
}
Settings related to message display.

Fields

code_set: Option<String>

The code set to use when displaying messages in the current locale. Note that this does not return standard code set identifiers and so this value cannot be used with the codes::codesets module.

multibyte_max_bytes: Option<u32>

The maximum number of bytes needed to represent a single wide character in the current locale.