pub struct SignFormat {
pub currency_symbol_precedes: bool,
pub space_separated: bool,
pub sign_location: SignLocation,
}Expand description
This denotes the complete handling of sign placement for a currency value.
Fields
currency_symbol_precedes: boolThe currency symbol precedes (or follows) the numeric value.
space_separated: boolA space separates the numeric value and currency symbol.
sign_location: SignLocationPlacement of the sign symbol.