pub enum SignLocation {
UseParenthesis,
BeforeString,
AfterString,
BeforeCurrencySymbol,
AfterCurrencySymbol,
}Expand description
This enumeration defines the handling of sign placement and choice for either positive or negative numeric values. The examples for each use a value of minus 999.99.
Note that one format that cannot be easily represented here is the often used spreadsheet accounting format where the numeric part of the value is right aligned but currency symbols are left aligned in a cell and parenthesis are used to denote negatives but again the opening parenthesis is left aligned and the closing parenthesis is right aligned.
Variants
UseParenthesis
Use parenthesis ($999.99) around the value to denote sign.
BeforeString
Place a symbol before the value $-999.99.
AfterString
Place a symbol after the value $999.99-.
BeforeCurrencySymbol
Place a symbol before the currency sign -$999.99.
AfterCurrencySymbol
Place a symbol after the currency sign $-999.99.